adk_lake_shapes: Return path to Lake Polygons Shapefile

View source: R/adk_lake_shapes.R

adk_lake_shapesR Documentation

Return path to Lake Polygons Shapefile

Description

Returns the path to the shapefile for the study Lake polygons. The source is a locally stored shapefile that can be used for mapping and analysis.

Usage

adk_lake_shapes()

Examples

## Not run: 
#' library(sf)
bl = sf::read_sf(adklakedata::adk_shape())
lakes = sf::read_sf(adklakedata::adk_lake_shapes())
plot(st_geometry(bl))
plot(st_geometry(lakes), add=TRUE, col='blue')

## End(Not run)



adklakedata documentation built on June 2, 2026, 9:08 a.m.