check_dl_data: Download lake data from internet

View source: R/check_dl_data.R

check_dl_dataR Documentation

Download lake data from internet

Description

Check that we have local cache of ADK lake data. If it is not locally available, download the data from the internet and prepare it for local use. This only needs to be run once for each install of the package. Note: you will be required to re-download data when a new version of the package is released. This ensures stale data are not being accidentally used.

Usage

check_dl_data()

adklakedata documentation built on June 2, 2026, 9:08 a.m.