View source: R/check_dl_data.R
| set_local_path | R Documentation |
Data files are locally cached (they are too large to be distributed
with the CRAN package). These cached files are stored in your user
data directory, or a custom directory set using set_local_path.
set_local_path(path)
path |
Full path to custom folder, will be created if it doesn't exist. |
# set custom path to local temp directory
set_local_path(tempdir())
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.