Learn R Programming

adklakedata (version 0.6.4)

adk_lake_shapes: Return path to Lake Polygons Shapefile

Description

Returns the path to the shapefile for the study Lake polygons. The source is a locally stored shapefile that can be used for mapping and analysis.

Usage

adk_lake_shapes()

Arguments

Examples

Run this code
if (FALSE) {
#' library(sf)
bl = sf::read_sf(adklakedata::adk_shape())
lakes = sf::read_sf(adklakedata::adk_lake_shapes())
plot(st_geometry(bl))
plot(st_geometry(lakes), add=TRUE, col='blue')
}


Run the code above in your browser using DataLab