powered by
Returns the path to the shapefile for the study Lake polygons. The source is a locally stored shapefile that can be used for mapping and analysis.
adk_lake_shapes()
if (FALSE) { #' library(sf) bl = sf::read_sf(adklakedata::adk_shape()) lakes = sf::read_sf(adklakedata::adk_lake_shapes()) plot(st_geometry(bl)) plot(st_geometry(lakes), add=TRUE, col='blue') }
Run the code above in your browser using DataLab