Learn R Programming

adklakedata (version 0.6.4)

adk_shape: Return path to Adirondack Park Shapefile

Description

Returns the path to the shapefile for the Adirondack Park outline (The "Blue Line"). Returns the path to a locally stored shapefile that can be used for mapping and analysis.

Usage

adk_shape()

Arguments

Examples

Run this code
if (FALSE) {
#' library(sf)
bl = sf::read_sf(adklakedata::adk_shape())
lakes = sf::read_sf(adklakedata::adk_lake_shapes())
plot(st_geometry(bl))
plot(st_geometry(lakes), add=TRUE, col='blue')
}


Run the code above in your browser using DataLab